@@ -141,32 +141,49 @@ class TestPandas(unittest.TestCase):
 
     def test_replace_all_bools_with_strings(self):
         results = replace_all_bools_with_strings(series=pd.Series([True]))
-        self.assertEqual(results.values.tolist(), ['True'])
+        self.assertEqual(list(results), ['True'])
         results = replace_all_bools_with_strings(series=pd.Series([False]))
-        self.assertEqual(results.values.tolist(), ['False'])
+        self.assertEqual(list(results), ['False'])
         results = replace_all_bools_with_strings(series=pd.Series([True, False]))
-        self.assertEqual(results.values.tolist(), ['True', 'False'])
+        self.assertEqual(list(results), ['True', 'False'])
         results = replace_all_bools_with_strings(series=pd.Series([True, False]).astype('category'))
-        self.assertEqual(results.values.tolist(), ['True', 'False'])
+        self.assertEqual(list(results), ['True', 'False'])
         results = replace_all_bools_with_strings(series=pd.Series([True, False, None]))
-        self.assertEqual(results.values.tolist(), ['True', 'False', None])
+        self.assertEqual(list(results), ['True', 'False', None])
         results = replace_all_bools_with_strings(series=pd.Series([True, False, np.nan]))
-        self.assertEqual(results.values.tolist(), ['True', 'False', np.nan])
+        self.assertEqual(list(results), ['True', 'False', np.nan])
         results = replace_all_bools_with_strings(series=pd.Series([None, True, False, None]))
-        self.assertEqual(results.values.tolist(), [None, 'True', 'False', None])
+        self.assertEqual(list(results), [None, 'True', 'False', None])
         results = replace_all_bools_with_strings(series=pd.Series([np.nan, True, False, np.nan]))
-        self.assertEqual(results.values.tolist(), [np.nan, 'True', 'False', np.nan])
+        self.assertEqual(list(results), [np.nan, 'True', 'False', np.nan])
+
+        results = replace_all_bools_with_strings(series=pd.Series(['True']))
+        self.assertEqual(list(results), ['True'])
+        results = replace_all_bools_with_strings(series=pd.Series(['False']))
+        self.assertEqual(list(results), ['False'])
+        results = replace_all_bools_with_strings(series=pd.Series(['True', 'False']))
+        self.assertEqual(list(results), ['True', 'False'])
+        results = replace_all_bools_with_strings(series=pd.Series(['True', 'False']).astype('category'))
+        self.assertEqual(list(results), ['True', 'False'])
+        results = replace_all_bools_with_strings(series=pd.Series(['True', 'False', None]))
+        self.assertEqual(list(results), ['True', 'False', None])
+        results = replace_all_bools_with_strings(series=pd.Series(['True', 'False', np.nan]))
+        self.assertEqual(list(results), ['True', 'False', np.nan])
+        results = replace_all_bools_with_strings(series=pd.Series([None, 'True', 'False', None]))
+        self.assertEqual(list(results), [None, 'True', 'False', None])
+        results = replace_all_bools_with_strings(series=pd.Series([np.nan, 'True', 'False', np.nan]))
+        self.assertEqual(list(results), [np.nan, 'True', 'False', np.nan])
 
         results = replace_all_bools_with_strings(series=pd.Series([], dtype=object))
-        self.assertEqual(results.values.tolist(), [])
+        self.assertEqual(list(results), [])
         results = replace_all_bools_with_strings(series=pd.Series(['Whatever']))
-        self.assertEqual(results.values.tolist(), ['Whatever'])
+        self.assertEqual(list(results), ['Whatever'])
         results = replace_all_bools_with_strings(series=pd.Series([True, False, 'Whatever']))
-        self.assertEqual(results.values.tolist(), ['True', 'False', 'Whatever'])
+        self.assertEqual(list(results), ['True', 'False', 'Whatever'])
         results = replace_all_bools_with_strings(series=pd.Series([True, False, TestEnum.VALUE_A]))
-        self.assertEqual(results.values.tolist(), ['True', 'False', TestEnum.VALUE_A])
+        self.assertEqual(list(results), ['True', 'False', TestEnum.VALUE_A])
         results = replace_all_bools_with_strings(series=pd.Series([None]))
-        self.assertEqual(results.values.tolist(), [None])
+        self.assertEqual(list(results), [None])
         results = replace_all_bools_with_strings(series=pd.Series([np.nan]))
         self.assertEqual(len(results), 1)
 
@@ -554,7 +571,7 @@ class TestPandas(unittest.TestCase):
         self.helper_test_summary(get_test_path() + '/test_files/pandas/test_non_numeric_summary__style__credit__all_missing__sorted.html',
                                  clean_formatted_dataframe(non_numeric_summary(test_data, return_style=True, sort_by_columns=True).render()))
 
-    def test_non_numeric_summarytest_non_numeric_summary_test(self):
+    def test_non_numeric_summary2(self):
         test_data = self.credit_data.copy()
         test_data['purpose'] = test_data['purpose'].replace({'radio/tv': '1111111111222222222233333333334444444444'})
         test_data.loc[25:75, ['checking_status']] = np.nan
@@ -736,9 +753,9 @@ class TestPandas(unittest.TestCase):
                                   remove_first_level_duplicates=remove_first_level_duplicates,
                                   return_style=False)
 
-            file_name = get_test_path() + f'/test_files/pandas/count_groups_{group_1}_{group_2}_' \
-                                          f'{group_sum}_{remove_first_level_duplicates}.txt'
-            with redirect_stdout_to_file(file_name):
+            name = get_test_path() + f'/test_files/pandas/count_groups_{group_1}_{group_2}_' \
+                                     f'{group_sum}_{remove_first_level_duplicates}.txt'
+            with redirect_stdout_to_file(name):
                 print_dataframe(counts)
             return counts
 
